#ifndef NT2_INCLUDE_FUNCTIONS_CHOL_HPP_INCLUDED
#define NT2_INCLUDE_FUNCTIONS_CHOL_HPP_INCLUDED

#include <nt2/linalg/include/functions/chol.hpp>

#endif
